@@ -16,4 +16,9 @@ EXPLORER_PERMISSION_VIEW = getattr(settings, 'EXPLORER_PERMISSION_VIEW', lambda
 
 EXPLORER_PERMISSION_CHANGE = getattr(settings, 'EXPLORER_PERMISSION_CHANGE', lambda u: u.is_staff)
 
-EXPLORER_RECENT_QUERY_COUNT = getattr(settings, 'EXPLORER_RECENT_QUERY_COUNT', 10)
\ No newline at end of file
+EXPLORER_RECENT_QUERY_COUNT = getattr(settings, 'EXPLORER_RECENT_QUERY_COUNT', 10)
+
+# This is callable instead of a static attribute so that it gets reevaluated on every call.
+# This aids testability. Otherwise this property gets loaded at the beginning of the test run
+# and can't be overridden. There is surely a better pattern for this, but this'll hold for now.
+EXPLORER_GET_USER_QUERY_VIEWS = lambda: getattr(settings, 'EXPLORER_USER_QUERY_VIEWS', {})
\ No newline at end of file
