@@ -10,5 +10,5 @@ urlpatterns = patterns('',
     url(r'csv$', 'explorer.views.csv_from_sql', name='generate_csv'),
     url(r'schema/$', 'explorer.views.schema', name='explorer_schema'),
     url(r'logs/$', ListQueryLogView.as_view(), name='explorer_logs'),
-    url(r'$', ListQueryView.as_view(), name='explorer_index'),
+    url(r'^$', ListQueryView.as_view(), name='explorer_index'),
 )
\ No newline at end of file
